@@ -87,7 +87,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                 {
                     GMM_ASSERTDPF(!CreateParams.Flags.Info.StdSwizzle, "StdSwizzle not supported on current platform");
 
-                    if((!GetGmmLibContext()->GetWaTable().WaDefaultTile4) || (!GetGmmLibContext()->GetSkuTable().FtrForceTile4))
+                    if(!GetGmmLibContext()->GetSkuTable().FtrForceTile4) // FtrForceTile4 should never be set by default, used for debug purpose only
                     {
                         // Default Tiling is set to Tile64 on FtrTileY disabled platforms
                         uint8_t IsYUVSurface = GmmIsPlanar(CreateParams.Format) ||
@@ -125,7 +125,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                     GMM_ASSERTDPF(0, "Tile Yf/Ys not supported on given platform");
 
                     // Overrides the flags.
-                    if((GetGmmLibContext()->GetWaTable().WaDefaultTile4) || (GetGmmLibContext()->GetSkuTable().FtrForceTile4))
+                    if(GetGmmLibContext()->GetSkuTable().FtrForceTile4)// FtrForceTile4 should never be set by default, used for debug purpose only.
                     {
                         CreateParams.Flags.Info.Tile64 = CreateParams.Flags.Info.TiledYs ||
                                                          (CreateParams.MSAA.NumSamples > 1) || CreateParams.Flags.Gpu.TiledResource; // Colour & Depth/Stencil(IMS) MSAA should use Tile64
@@ -148,8 +148,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
 
                 // On Xe_HP onwards translate UMD's TileY/TileYs request to Tile4/Tile64 respectively
                 // Exclude TileX, Linear from override
-                if((GetGmmLibContext()->GetWaTable().WaDefaultTile4 || GetGmmLibContext()->GetSkuTable().FtrForceTile4) && (CreateParams.Flags.Info.TiledYs ||
-                                                                       CreateParams.Flags.Info.TiledY))
+                if((GetGmmLibContext()->GetSkuTable().FtrForceTile4) && (CreateParams.Flags.Info.TiledYs || CreateParams.Flags.Info.TiledY))
                 {
                     CreateParams.Flags.Info.Tile64 =
                     CreateParams.Flags.Info.TiledYs ||
@@ -246,7 +245,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                                      GMM_GTT_CACHETYPE_UNCACHED;
     }
 
-    if(GetGmmLibContext()->GetSkuTable().FtrCameraCaptureCaching == FALSE &&
+    if(GetGmmLibContext()->GetSkuTable().FtrCameraCaptureCaching == false &&
        CreateParams.Flags.Gpu.CameraCapture)
     {
         Surf.Flags.Info.Cacheable = 0;
@@ -285,14 +284,35 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
     }
 
     // Memory optimization for 64KB tiled Surface.
-    if(GetGmmLibContext()->GetWaTable().WaTile64Optimization && Optimize64KBTile)
+    if (!GetGmmLibContext()->GetSkuTable().FtrTileY)
     {
-        if(pTextureCalc->SurfaceRequires64KBTileOptimization(&Surf))
+        if ((GetGmmLibContext()->GetSkuTable().FtrTile64Optimization) && Optimize64KBTile)
         {
-            GMM_SET_64KB_TILE(Surf.Flags, 0, GetGmmLibContext());
-            GMM_SET_4KB_TILE(Surf.Flags, 1, GetGmmLibContext());
-            GMM_SET_64KB_TILE(CreateParams.Flags, 0, GetGmmLibContext());
-            GMM_SET_4KB_TILE(CreateParams.Flags, 1, GetGmmLibContext());
+            if ((GetGmmLibContext()->GetWaTable().Wa_14020040029) && (Surf.Flags.Gpu.Depth))
+            {
+                // if SW uses Tile4 merely to reduce surface size for Depth buffers,
+                // then use Tile64 instead
+                GMM_SET_64KB_TILE(Surf.Flags, 1, GetGmmLibContext());
+                GMM_SET_4KB_TILE(Surf.Flags, 0, GetGmmLibContext());
+
+                //Also update CreateParams, if client reuses the modified struct, it'd see final tile-selection by Gmm.
+                //Gmm's auto-tile-selection & tile-mode for size-optimization doesn't work for explicit tile-selection
+                GMM_SET_64KB_TILE(CreateParams.Flags, 1, GetGmmLibContext());
+                GMM_SET_4KB_TILE(CreateParams.Flags, 0, GetGmmLibContext());
+            }
+            else
+            {
+                if (pTextureCalc->SurfaceRequires64KBTileOptimization(&Surf))
+                {
+                    GMM_SET_64KB_TILE(Surf.Flags, 0, GetGmmLibContext());
+                    GMM_SET_4KB_TILE(Surf.Flags, 1, GetGmmLibContext());
+
+                    //Also update CreateParams, if client reuses the modified struct, it'd see final tile-selection by Gmm.
+                    //Gmm's auto-tile-selection & tile-mode for size-optimization doesn't work for explicit tile-selection
+                    GMM_SET_64KB_TILE(CreateParams.Flags, 0, GetGmmLibContext());
+                    GMM_SET_4KB_TILE(CreateParams.Flags, 1, GetGmmLibContext());
+                }
+            }
         }
     }
 
@@ -312,8 +332,15 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
             AuxSurf.Flags.Gpu.CCS                = 0;
             AuxSurf.Type                         = (AuxSurf.Flags.Gpu.HiZ) ? AuxSurf.Type : RESOURCE_INVALID;
             AuxSurf.Flags.Info.RenderCompressed = AuxSurf.Flags.Info.MediaCompressed = 0;
+            AuxSurf.Flags.Info.NotCompressed                                         = 1;
         }
-        else if(Surf.Flags.Gpu.SeparateStencil && Surf.Flags.Gpu.CCS) //Stencil compression
+        else if(Surf.Flags.Gpu.Depth && Surf.Flags.Gpu.HiZ && !Surf.Flags.Gpu.CCS) // Depth + HiZ only, CCS is disabled
+        {
+            // main surface is depth, AuxSurf is HiZ
+            Surf.Flags.Gpu.HiZ                   = 0; //depth buffer, clear HiZ
+            AuxSurf.Flags.Gpu.IndirectClearColor = 0; //Clear fastClear from HiZ
+        }
+	else if(Surf.Flags.Gpu.SeparateStencil && Surf.Flags.Gpu.CCS) //Stencil compression
         {
             AuxSurf.Flags.Gpu.SeparateStencil = 0;
             Surf.Flags.Gpu.CCS                = 0;
@@ -332,6 +359,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
             AuxSecSurf.Flags.Gpu.MCS            = 0;
             AuxSurf.Flags.Gpu.CCS               = 0;
             AuxSurf.Flags.Info.RenderCompressed = AuxSurf.Flags.Info.MediaCompressed = 0;
+            AuxSurf.Flags.Info.NotCompressed                                         = 1;
         }
         else if(Surf.Flags.Gpu.CCS)
         {
@@ -364,6 +392,13 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
         MultiTileArch = CreateParams.MultiTileArch;
     }
 
+    // For Xe2 RenderCompressed and MediaCompressed to be unset
+    if (GetGmmLibContext()->GetSkuTable().FtrXe2Compression)
+    {
+        //Deny compression
+        Surf.Flags.Info.RenderCompressed = 0;
+        Surf.Flags.Info.MediaCompressed  = 0;
+    }
     return true;
 }
 
@@ -432,6 +467,12 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
     pPlatformResource = GMM_OVERRIDE_PLATFORM_INFO(&Surf, GetGmmLibContext());
     pTextureCalc      = GMM_OVERRIDE_TEXTURE_CALC(&Surf, GetGmmLibContext());
 
+    if (!pTextureCalc)
+    {
+        GMM_ASSERTDPF(0, "Texture Calculation pointer is NULL.");
+        goto ERROR_CASE;
+    }
+
     __GMM_ASSERT(!(
     Surf.Flags.Gpu.Query &&
     !Surf.Flags.Info.Cacheable)); // Why query not set as cacheable? If not cacheable, what keeps from stolen memory (because STORE_DWORD/PIPE_CONTROL/etc. targets can't be in stolen)?
@@ -547,6 +588,7 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
             Surf.Flags.Info.NonLocalOnly = 0;
         }
         if(GetGmmLibContext()->GetSkuTable().FtrFlatPhysCCS &&
+            !GetGmmLibContext()->GetSkuTable().FtrXe2Compression &&
            (Surf.Flags.Info.RenderCompressed ||
             Surf.Flags.Info.MediaCompressed))
         {
@@ -592,6 +634,30 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
     else
     {
         Surf.Flags.Info.LocalOnly = false; //Zero out on iGPU
+        if (GetGmmLibContext()->GetSkuTable().FtrXe2Compression && Surf.Flags.Info.XAdapter)
+        {
+            Surf.Flags.Info.NotCompressed     = 1; // disable compression for XAdapter resources on iGPU,
+            Surf.Flags.Gpu.CCS                = 0;
+            Surf.Flags.Gpu.UnifiedAuxSurface  = 0;
+            Surf.Flags.Gpu.IndirectClearColor = 0;
+            Surf.Flags.Gpu.MCS                = 0;
+        }
+    }
+    if (GetGmmLibContext()->GetSkuTable().FtrXe2Compression)
+    {
+        if (Surf.Flags.Info.TiledX)
+        {
+            if (!(Surf.Flags.Gpu.FlipChain || Surf.Flags.Gpu.Overlay))
+            {
+                GMM_ASSERTDPF(0, "TiledX request for non displayable");
+            }
+            Surf.Flags.Info.NotCompressed = 1; // disable compression for TileX resources
+        }
+
+        if ((Surf.Flags.Gpu.FlipChain || Surf.Flags.Gpu.Overlay) && !Surf.Flags.Info.Tile4)
+        {
+            Surf.Flags.Info.NotCompressed = 1; //Disable compression if displayable are not tile4
+        }
     }
 
     if((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) < IGFX_GEN8_CORE) &&
@@ -826,10 +892,9 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
     // IndirectClearColor Restrictions
     if((Surf.Flags.Gpu.IndirectClearColor) &&
        !( //--- Legitimate IndirectClearColor Case ------------------------------------------
-       ((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) >= IGFX_GEN9_CORE) &&
-        Surf.Flags.Gpu.UnifiedAuxSurface) ||
-       ((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) > IGFX_GEN11_CORE) &&
-        (Surf.Flags.Gpu.HiZ || Surf.Flags.Gpu.SeparateStencil))))
+        (((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) >= IGFX_GEN9_CORE) && Surf.Flags.Gpu.UnifiedAuxSurface) ||
+         ((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) > IGFX_GEN11_CORE) && (Surf.Flags.Gpu.HiZ || Surf.Flags.Gpu.SeparateStencil)))))
+
     {
         GMM_ASSERTDPF(0, "Invalid IndirectClearColor usage!");
         goto ERROR_CASE;
